import MuseScore 3.0
import QtQuick 2.0

MuseScore {

    version: "1.0";
    description: "This demo plugin adds new chords\n\n" +
                 "Comments, feedbacks, report bugs, ask for new features, contribute:\n" +
                 "https://github.com/rousselmanu/msc_plugins/";
    menuPath: "Plugins.Chords." + qsTr("Add Chord Demo")
       
    
   
    // create and return a new Note element with given pitch, tpc
	function createNote(pitch, tpc){
		//console.log("pitch = ", pitch, "tpc = ", tpc)
        var note = newElement(Element.NOTE);
        note.pitch = pitch;
		note.tpc = tpc;
        note.tpc1 = tpc;
        note.tpc2 = tpc;
        return note;
    }// end CreateNote
    
    function setCursorToTime(cursor, time){
        cursor.rewind(0);
        while (cursor.segment) { 
            var current_time = cursor.tick;
            if(current_time>=time){
                return true;
            }
            cursor.next();
        }
        cursor.rewind(0);
        return false;
    }// end setcursor To Time
	
    //adds chord at current position. chord_notes is an array with pitch of notes.
	function addChord(cursor, chord_notes, duration){ 
		for (var c = 0; c < chord_notes.length; c++){
			//console.log("chord_notes = ", chord_notes[c]);
		}
		if(chord_notes.length==0) return -1;
		var cur_time=cursor.tick;
		cursor.setDuration(duration, 1920);
		cursor.addNote(chord_notes[0]); //add 1st note
		
		var next_time=cursor.tick;
		setCursorToTime(cursor, cur_time); //rewind to this note
		var note = cursor.element.notes[0];
		note.tpc = chord_notes[4];
		
		var chord = cursor.element; //get the chord created when 1st note was inserted
				
		for(var i=1; i<4; i++){
			var note = createNote(chord_notes[i], chord_notes[i+4]);
			//console.log("note.pitch = ", note.pitch, "note.tpc = ", note.tpc);
			note.tpc = chord_notes[i+4];
			chord.add(note); //add notes to the chord
			chord.notes[i].tpc = chord_notes[i+4];
		}
		
		setCursorToTime(cursor, next_time);
		return 0;
	}//end AddChord
	
    
    onRun: {
        if (typeof curScore === 'undefined') {
            Qt.quit();
        }

        var cursor = curScore.newCursor(),
                startStaff,
                endStaff,
                endTick,
                fullScore = false;
                
        cursor.rewind(1);
        

        if (!cursor.segment) { // no selection
            fullScore = true;
            startStaff = 0; // start with 1st staff
            endStaff = curScore.nstaves - 1; // and end with last
        } else {
            startStaff = cursor.staffIdx;
            cursor.rewind(2);
            if (cursor.tick === 0) {
                // this happens when the selection includes
                // the last measure of the score.
                // rewind(2) goes behind the last segment (where
                // there's none) and sets tick=0
                endTick = curScore.lastSegment.tick + 1;
            } else {
                endTick = cursor.tick;
            }
            endStaff = cursor.staffIdx;
        }
        console.log(startStaff + " - " + endStaff + " - " + endTick);
        console.log('curScore.nstaves: ' + curScore.nstaves);
        console.log('cursor.tick: ' + cursor.tick);
        console.log('curScore.lastSegment.tick: ' + curScore.lastSegment.tick);

        cursor.rewind(1); // beginning of selection
        if (fullScore) { // no selection
            cursor.rewind(0); // beginning of score
        }
        cursor.voice = 0;
        
		console.log('cursor.staffIdx: ' + cursor.staffIdx);
		
        //cursor.track = 0;
        
		
		cursor.staffIdx = 1;
		
		// chords[0]: name
        // chords[1]: pitches lo-hi & tpc lo-hi
        // chords[2]: occurences of this voicing
        // chords[3]: instances of this chord name
     var chords = [
["A",[56,57,61,64,22,17,21,18],13,1], //g♯,a,c♯,e
["A6/9",[49,52,54,59,21,18,20,19],0,1], //c♯,e,f♯,b
["A7",[55,59,61,66,15,19,21,20],73,1], //g,b,c♯,f♯
["A7#11",[49,51,55,57,21,23,15,17],0,1], //c♯,d♯,g,a
["A7#9",[49,52,55,60,21,18,15,14],0,1], //c♯,e,g,c
["A7/C#",[49,54,55,59,21,20,15,19],5,1], //c♯,f♯,g,b
["A7alt",[55,60,61,65,15,14,9,13],38,1], //g,c,db,f
["A7b13",[55,59,61,65,15,19,21,13],0,1], //g,b,c♯,f
["A7b9",[55,58,61,66,15,12,21,20],5,2], //g,bb,c♯,f♯
["A7b9",[49,54,55,58,21,20,15,12],1,1], //c♯,f♯,g,bb
["A7sus",[55,57,62,64,15,17,16,18],1,1],   //g,a,d,e
["A7susb9",[46,50,55,57,24,16,15,17],0,1], //a♯,d,g,a
["Ab",[55,56,60,63,15,10,14,11],109,1], //g,ab,c,eb
["Ab/Eb",[51,55,56,60,11,15,10,14],5,1], //eb,g,ab,c
["Ab6/9",[48,51,53,58,14,11,13,12],0,1], //c,eb,f,bb
["Ab7",[54,58,60,65,8,12,14,13],83,1], //gb,bb,c,f
["Ab7#11",[56,60,62,66,10,14,16,8],1,2],   //ab,c,d,gb
["Ab7#11/Gb",[54,56,60,62,8,10,14,16],2,1],   //gb,ab,c,d
["Ab7#9",[48,54,56,59,14,8,10,7],0,1], //c,gb,ab,cb
["Ab7/C",[48,53,54,58,14,13,8,12],5,1], //c,f,gb,bb
["Ab7alt",[54,59,60,64,20,19,14,18],4,1], //f♯,b,c,e
["Ab7b13",[54,58,60,64,8,12,14,6],1,1], //gb,bb,c,fb
["Ab7b9",[48,53,54,57,14,13,8,17],2,1], //c,f,gb,a
["Ab7sus",[46,53,54,56,12,13,8,10],0,1], //bb,f,gb,ab
["Ab7susb9",[49,54,56,57,9,8,10,17],0,1], //db,gb,ab,a
["Abdim",[56,59,62,65,10,19,16,13],10,1], //ab,b,d,f
["Abm(6/9)",[47,53,56,58,19,13,10,12],0,1], //b,f,ab,bb
["Abm6",[56,59,63,65,10,19,11,13],0,1], //ab,b,eb,f
["Abm7",[54,58,59,63,8,12,7,11],25,1], //gb,bb,cb,eb
["Abm7#5",[47,52,54,56,19,6,8,10],0,1], //b,fb,gb,ab
["Abm7b5",[54,56,59,62,8,10,19,16],1,1],   //gb,ab,b,d
["AbMaj#11",[56,60,62,67,10,14,16,15],0,1], //ab,c,d,g
["AbMaj#5",[48,52,55,56,14,18,15,10],0,1], //c,e,g,ab
["AbmMaj7",[55,56,59,63,15,10,19,11],5,1],   //g,ab,b,eb
["Adim",[57,60,63,66,17,14,11,20],4,1], //a,c,eb,f♯
["Am(6/9)",[48,54,57,59,14,20,17,19],0,1], //c,f♯,a,b
["Am6",[57,60,64,66,17,14,18,20],0,1], //a,c,e,f♯
["Am7",[55,59,60,64,15,19,14,18],132,1], //g,b,c,e
["Am7#5",[45,48,53,55,17,14,13,15],0,1], //a,c,f,g
["Am7b5",[55,57,60,63,15,17,14,11],51,1], //g,a,c,eb
["AMaj#11",[49,51,56,59,21,23,22,19],0,1], //c♯,d♯,g♯,b
["AMaj#5",[57,61,65,68,17,21,25,22],0,1], //a,c♯,e♯,g♯
["AmMaj7",[45,48,52,56,17,14,18,22],0,1], //a,c,e,g♯
["B",[51,54,58,59,23,20,24,19],8,4], //d♯,f♯,a♯,b
["B",[58,59,63,66,24,19,23,20],2,1], //a♯,b,d♯,f♯
["B",[47,51,54,58,19,23,20,24],2,1], //b,d♯,f♯,a♯
["B6/9",[51,54,56,61,23,20,22,21],0,1], //d♯,f♯,g♯,c♯
["B7",[51,56,57,61,23,22,17,21],47,1], //d♯,g♯,a,c♯
["B7#11",[57,59,63,65,17,19,11,13],1,1], //a,b,eb,f
["B7#9",[51,57,59,62,23,17,19,16],0,1], //d♯,a,b,d
["B7alt",[51,55,57,62,11,15,17,16],11,1], //eb,g,a,d
["B7b13",[57,61,63,67,17,21,23,15],0,1], //a,c♯,d♯,g
["B7b9",[51,56,57,60,23,22,17,14],5,1], //d♯,g♯,a,c
["B7sus",[47,52,54,57,19,18,20,17],0,1], //b,e,f♯,a
["B7susb9",[47,48,52,57,19,14,18,17],0,1], //b,c,e,a
["Bb",[57,58,62,65,17,12,16,13],46,1], //a,bb,d,f
["Bb/D",[50,53,57,58,16,13,17,12],2,1], //d,f,a,bb
["Bb6/9",[50,53,55,60,16,13,15,14],0,1], //d,f,g,c
["Bb7",[50,55,56,60,16,15,10,14],173,2], //d,g,ab,c
["Bb7",[56,60,62,67,10,14,16,15],3,1], //ab,c,d,g
["Bb7#11",[52,56,58,62,18,10,12,16],4,1],   //e,ab,bb,d
["Bb7#9",[50,56,58,61,16,10,12,9],0,1], //d,ab,bb,db
["Bb7/Ab",[56,60,62,67,10,14,16,15],39,1], //ab,c,d,g
["Bb7alt",[50,54,56,61,16,20,22,21],19,2], //d,f♯,g♯,c♯
["Bb7alt",[56,61,62,66,22,21,16,20],10,1], //g♯,c♯,d,f♯
["Bb7b13",[56,60,62,66,10,14,16,8],1,1], //ab,c,d,gb
["Bb7b9",[50,55,56,59,16,15,10,19],15,2], //d,g,ab,b
["Bb7b9",[56,59,62,67,10,19,16,15],2,1], //ab,b,d,g
["Bb7sus",[51,53,56,58,11,13,10,12],6,2], //eb,f,ab,bb
["Bb7sus",[53,56,58,63,13,10,12,11],1,1], //f,ab,bb,eb
["Bb7susb9",[47,51,56,58,19,11,10,12],0,1], //b,eb,ab,bb
["Bbdim",[46,49,52,55,12,21,18,15],1,1], //bb,c♯,e,g
["Bbm(6/9)",[49,55,58,60,9,15,12,14],0,1], //db,g,bb,c
["Bbm6",[58,61,65,67,12,9,13,15],0,1], //bb,db,f,g
["Bbm7",[56,60,61,65,10,14,9,13],93,1], //ab,c,db,f
["Bbm7#5",[46,49,54,56,12,9,8,10],0,1], //bb,db,gb,ab
["Bbm7b5",[56,58,61,64,10,12,9,18],2,1], //ab,bb,db,e
["BbMaj#11",[46,50,52,57,12,16,18,17],0,1], //bb,d,e,a
["Bbmaj#11",[50,52,57,60,16,18,17,14],0,1], //d,e,a,c
["BbMaj#5",[46,50,54,57,12,16,20,17],0,1], //bb,d,f♯,a
["BbmMaj7",[57,58,61,65,17,12,9,13],10,2], //a,bb,db,f
["BbmMaj7",[49,53,57,60,9,13,17,14],0,1], //db,f,a,c
["Bdim",[47,50,53,56,19,16,13,10],1,1], //b,d,f,ab
["Bm(6/9)",[50,56,59,61,16,22,19,21],0,1], //d,g♯,b,c♯
["Bm6",[59,62,66,68,19,16,20,22],0,1], //b,d,f♯,g♯
["Bm7",[57,61,62,66,17,21,16,20],52,1], //a,c♯,d,f♯
["Bm7#5",[47,50,55,57,19,16,15,17],0,1], //b,d,g,a
["Bm7b5",[57,59,62,65,17,19,16,13],17,1], //a,b,d,f
["BMaj#11",[51,53,58,61,23,13,24,21],0,1], //d♯,f,a♯,c♯
["BMaj#5",[47,51,55,58,19,23,15,24],0,1], //b,d♯,g,a♯
["BmMaj7",[58,59,62,66,24,19,16,20],0,1], //a♯,b,d,f♯
["C",[48,52,55,59,14,18,15,19],67,3], //c,e,g,b
["C",[52,55,57,62,18,15,17,16],38,1], //e,g,a,d
["C",[59,60,64,67,19,14,18,15],2,1], //b,c,e,g
["C#dim",[49,52,55,58,21,18,15,12],8,1], //c♯,e,g,bb
["C#m7",[52,56,59,63,18,22,19,23],17,1], //e,g♯,b,d♯
["C#m7#5",[49,52,57,59,21,18,17,19],0,1], //c♯,e,a,b
["C#m7b5",[49,54,55,59,21,20,15,19],1,2], //c♯,f♯,g,b
["C#m7b5",[49,52,55,59,21,18,15,19],1,1], //c♯,e,g,b
["C#mMaj7",[52,56,60,63,18,22,14,23],0,1], //e,g♯,c,d♯
["C/C",[48,52,55,59,14,18,15,19],1,1], //c,e,g,b
["C/E",[52,55,59,60,18,15,19,14],11,1], //e,g,b,c
["C/G",[55,59,60,64,15,19,14,18],1,1], //g,b,c,e
["C6/9",[52,55,57,62,18,15,17,16],0,1], //e,g,a,d
["C7",[52,57,58,62,18,17,12,16],161,1], //e,a,bb,d
["C7#11",[52,54,58,62,18,20,12,16],0,1], //e,f♯,bb,d
["C7#9",[52,58,60,63,18,12,14,11],0,1], //e,bb,c,eb
["C7alt",[52,56,58,63,18,10,12,11],34,1], //e,ab,bb,eb
["C7b13",[52,56,58,62,18,10,12,16],1,2], //e,ab,bb,d
["C7b13",[48,52,56,58,14,18,10,12],0,1], //c,e,ab,bb
["C7b9",[52,57,58,61,18,17,12,9],27,1], //e,a,bb,db
["C7sus",[53,55,58,60,13,15,12,14],2,1], //f,g,bb,c
["C7susb9",[48,49,53,58,14,9,13,12],0,1], //c,db,f,bb
["Cdim",[48,51,54,57,14,11,20,17],0,1], //c,eb,f♯,a
["Cm(6/9)",[51,57,60,62,11,17,14,16],0,1], //eb,a,c,d
["Cm6",[48,51,55,57,14,11,15,17],4,1], //c,eb,g,a
["Cm7",[51,55,58,62,11,15,12,16],173,3], //eb,g,bb,d
["Cm7",[48,51,55,58,14,11,15,12],23,1], //c,eb,g,bb
["Cm7",[58,62,63,67,12,16,11,15],7,1], //bb,d,eb,g
["Cm7#5",[48,51,56,58,14,11,10,12],3,1], //c,eb,ab,bb
["Cm7b5",[48,53,54,58,14,13,8,12],5,2], //c,f,gb,bb
["Cm7b5",[48,51,54,58,14,11,8,12],2,1], //c,eb,gb,bb
["CMaj#11",[52,54,59,62,18,20,19,16],0,1], //e,f♯,b,d
["CMaj#5",[48,52,56,59,14,18,22,19],0,1], //c,e,g♯,b
["CmMaj7",[51,55,59,62,11,15,19,16],16,2], //eb,g,b,d
["CmMaj7",[48,51,55,59,14,11,15,19],1,1], //c,eb,g,b
["D",[54,57,61,62,20,17,21,16],3,3], //f♯,a,c♯,d
["D",[49,50,54,57,21,16,20,17],1,1], //c♯,d,f♯,a
["D",[50,54,57,61,16,20,17,21],1,1], //d,f♯,a,c♯
["D#m7b5",[54,57,61,64,20,17,21,18],0,1], //f♯,a,c♯,e
["D6/9",[54,57,59,64,20,17,19,18],0,1], //f♯,a,b,e
["D7",[54,59,60,64,20,19,14,18],159,1], //f♯,b,c,e
["D7#11",[50,54,56,60,16,20,22,14],0,1], //d,f♯,g♯,c
["D7#9",[54,60,62,65,20,14,16,13],0,1], //f♯,c,d,f
["D7/A",[57,60,62,66,17,14,16,20],3,1], //a,c,d,f♯
["D7/D",[48,52,54,59,14,18,20,19],0,1], //c,e,f♯,b
["D7alt",[54,58,60,65,8,12,14,13],33,1], //gb,bb,c,f
["D7alt/C",[48,53,54,58,14,13,8,12],1,1], //c,f,gb,bb
["D7b13",[54,58,60,64,20,12,14,18],1,1],   //f♯,bb,c,e
["D7b9",[54,59,60,63,20,19,14,11],16,2], //f♯,b,c,eb
["D7b9",[48,51,54,59,14,11,20,19],0,1], //c,eb,f♯,b
["D7sus",[55,57,60,62,15,17,14,16],0,1], //g,a,c,d
["D7susb9",[50,51,55,60,16,23,15,14],0,1], //d,d♯,g,c
["Db",[53,56,60,61,13,10,14,9],17,1], //f,ab,c,db
["Db/Ab",[56,60,61,65,10,14,9,13],5,1], //ab,c,db,f
["Db/C",[48,49,53,56,14,9,13,10],11,1], //c,db,f,ab
["Db/Db",[49,53,56,60,9,13,10,14],1,1], //db,f,ab,c
["Db/F",[53,56,60,61,13,10,14,9],18,1], //f,ab,c,db
["Db6/9",[53,56,58,63,13,10,12,11],1,1], //f,ab,bb,eb
["Db7",[53,58,59,63,13,12,7,11],99,1], //f,bb,cb,eb
["Db7#11",[49,53,55,59,9,13,15,19],0,1], //db,f,g,b
["Db7#9",[53,59,61,64,13,19,9,18],0,1], //f,b,db,e
["Db7alt",[53,57,59,64,13,17,19,18],2,1], //f,a,b,e
["Db7b13",[49,53,57,59,9,13,17,19],0,1], //db,f,a,b
["Db7b9",[53,58,59,62,13,12,7,16],0,1], //f,bb,cb,d
["Db7sus",[49,51,54,59,9,11,8,19],0,1], //db,eb,gb,b
["Db7susb9",[49,50,54,59,9,16,8,19],0,1], //db,d,gb,b
["Dbdim",[49,52,55,58,21,18,15,12],0,1], //c♯,e,g,bb
["Dbm(6/9)",[52,58,61,63,18,24,21,23],0,1], //e,a♯,c♯,d♯
["Dbm6",[49,52,56,58,9,18,10,12],0,1], //db,e,ab,bb
["Dbm7",[52,56,59,63,18,10,19,11],4,1], //e,ab,b,eb
["DbMaj#11",[51,53,55,60,11,13,15,14],0,1], //eb,f,g,c
["DbMaj#5",[49,53,57,60,9,13,17,14],0,1], //db,f,a,c
["DbmMaj7",[49,52,56,60,9,18,10,14],3,1], //db,e,ab,c
["DbmMaj7/Ab",[56,60,61,64,10,14,9,18],2,1], //ab,c,db,e
["Ddim",[50,53,56,59,16,13,10,19],1,1],   //d,f,ab,b
["Dm(6/9)",[53,59,62,64,13,19,16,18],0,1], //f,b,d,e
["Dm6",[50,53,57,59,16,13,17,19],0,1], //d,f,a,b
["Dm7",[53,57,60,64,13,17,14,18],179,1], //f,a,c,e
["Dm7/D",[50,53,57,60,16,13,17,14],1,1],   //d,f,a,c
["DmMaj7/C#",[49,50,53,57,21,16,13,17],1,1],   //c♯,d,f,a
["Dm7/C",[48,50,53,57,14,16,13,17],1,1],   //c,d,f,a
["Dm7#5",[50,53,58,60,16,13,12,14],0,1], //d,f,bb,c
["Dm7/D",[50,53,57,60,16,13,17,14],22,1], //d,f,a,c
["Dm7b5",[50,55,56,60,16,15,10,14],71,1], //d,g,ab,c
["Dm7b5/Ab",[56,60,62,65,10,14,16,13],2,1], //ab,c,d,f
["DMaj#11",[52,54,56,61,18,20,22,21],0,1], //e,f♯,g♯,c♯
["DMaj#5",[50,54,58,61,16,20,24,21],0,1], //d,f♯,a♯,c♯
["DmMaj7",[53,57,61,64,13,17,21,18],1,2], //f,a,c♯,e
["DmMaj7",[49,50,53,57,21,16,13,17],0,1], //c♯,d,f,a
["E",[51,52,56,59,23,18,22,19],12,2], //d♯,e,g♯,b
["E",[56,59,63,64,22,19,23,18],2,1], //g♯,b,d♯,e
["E6/9",[56,59,61,66,22,19,21,20],0,1], //g♯,b,c♯,f♯
["E7",[56,61,62,66,22,21,16,20],81,1], //g♯,c♯,d,f♯
["E7#11",[52,56,58,62,18,22,24,16],2,1],   //e,g♯,a♯,d
["E7#9",[56,62,64,67,22,16,18,15],0,1], //g♯,d,e,g
["E7/D",[50,54,56,61,16,20,22,21],8,1], //d,f♯,g♯,c♯
["E7alt",[56,60,62,67,10,14,16,15],11,2], //ab,c,d,g
["E7alt",[50,55,56,60,16,15,10,14],4,1], //d,g,ab,c
["E7b13",[56,60,62,66,22,14,16,20],0,1], //g♯,c,d,f♯
["E7b9",[56,61,62,65,22,21,16,13],8,2], //g♯,c♯,d,f
["E7b9",[50,53,56,61,16,13,22,21],0,1], //d,f,g♯,c♯
["E7sus",[57,59,62,64,17,19,16,18],1,2], //a,b,d,e
["E7sus",[52,54,57,62,18,20,17,16],0,1], //e,f♯,a,d
["E7susb9",[52,53,57,62,18,13,17,16],0,1], //e,f,a,d
["Eb",[50,51,55,58,16,11,15,12],115,1], //d,eb,g,bb
["Eb/Eb",[51,55,58,62,11,15,12,16],11,1], //eb,g,bb,d
["Eb/G",[55,58,62,63,15,12,16,11],17,1], //g,bb,d,eb
["Eb6/9",[55,58,60,65,15,12,14,13],0,1], //g,bb,c,f
["Eb7",[55,60,61,65,15,14,9,13],180,1], //g,c,db,f
["Eb7#11",[51,55,57,61,11,15,17,9],1,1],   //eb,g,a,db
["Eb7#11/G",[55,57,61,63,15,17,9,11],1,1], //g,a,db,eb
["Eb7#9",[55,61,63,66,15,9,11,8],0,1], //g,db,eb,gb
["Eb7alt",[55,59,61,66,15,19,21,20],9,2], //g,b,c♯,f♯
["Eb7alt",[49,54,55,59,21,20,15,19],0,1], //c♯,f♯,g,b
["Eb7b13",[51,55,59,61,11,15,19,9],0,1], //eb,g,b,db
["Eb7b9",[55,60,61,64,15,14,9,18],1,2], //g,c,db,e
["Eb7b9",[49,52,55,60,9,18,15,14],1,1], //db,e,g,c
["Eb7sus",[56,58,61,63,10,12,9,11],7,2], //ab,bb,db,eb
["Eb7sus",[51,56,58,61,11,10,12,9],1,1], //eb,ab,bb,db
["Eb7susb9",[51,52,56,61,11,18,10,9],0,1], //eb,e,ab,db
["Ebdim",[51,54,57,60,11,20,17,14],20,1], //eb,f♯,a,c
["Ebm(6/9)",[48,51,53,54,14,11,13,8],0,1], //c,eb,f,gb
["Ebm6",[51,54,58,60,11,8,12,14],0,1], //eb,gb,bb,c
["Ebm7",[54,58,61,65,8,12,9,13],31,3], //gb,bb,db,f
["Ebm7",[49,51,54,58,9,11,8,12],12,1], //db,eb,gb,bb
["Ebm7",[51,54,58,61,11,8,12,9],3,1], //eb,gb,bb,db
["Ebm7",[49,53,54,58,9,13,8,12],2,1], //db,f,gb,bb
["Ebm7#5",[51,54,59,61,11,8,19,9],0,1], //eb,gb,b,db
["Ebm7/Db",[49,51,54,58,9,11,8,12],2,1], //db,eb,gb,bb
["Ebm7b5",[51,54,57,61,23,20,17,21],0,1], //d♯,f♯,a,c♯
["EbMaj#11",[51,55,57,62,11,15,17,16],3,1], //eb,g,a,d
["EbMaj#5",[51,55,59,62,11,15,19,16],0,1], //eb,g,b,d
["EbMajb13",[51,55,59,62,11,15,19,16],2,1],   //eb,g,b,d
["EbmMaj7",[50,51,54,58,16,11,8,12],5,3], //d,eb,gb,bb
["EbmMaj7",[51,54,58,62,11,8,12,16],3,1], //eb,gb,bb,d
["EbmMaj7",[54,58,62,65,8,12,16,13],3,1], //gb,bb,d,f
["Edim",[52,55,58,61,18,15,12,21],24,1], //e,g,bb,c♯
["Em(6/9)",[49,52,54,55,21,18,20,15],0,1], //c♯,e,f♯,g
["Em6",[52,55,59,61,18,15,19,21],0,1], //e,g,b,c♯
["Em7",[55,59,62,66,15,19,16,20],31,3], //g,b,d,f♯
["Em7",[52,55,59,62,18,15,19,16],4,1], //e,g,b,d
["Em7",[50,52,55,59,16,18,15,19],2,1], //d,e,g,b
["Em7#5",[52,55,60,62,18,15,14,16],0,1], //e,g,c,d
["Em7/D",[50,52,55,59,16,18,15,19],2,1], //d,e,g,b
["Em7/E",[52,55,59,62,18,15,19,16],6,1], //e,g,b,d
["Em7b5",[52,57,58,62,18,17,12,16],42,1], //e,a,bb,d
["EMaj#11",[54,56,58,63,20,22,24,23],0,1], //f♯,g♯,a♯,d♯
["EMaj#5",[52,56,60,63,18,22,26,23],0,1], //e,g♯,b♯,d♯
["EmMaj7",[51,52,55,59,23,18,15,19],0,1], //d♯,e,g,b
["EmMaj7/D#",[51,52,55,59,23,18,15,19],1,1], //d♯,e,g,b
["F",[52,53,57,60,18,13,17,14],107,1], //e,f,a,c
["F#",[49,53,54,58,9,13,8,12],0,1], //db,f,gb,bb
["F#7",[52,56,58,63,18,22,24,23],20,2], //e,g♯,a♯,d♯
["F#7",[52,54,58,61,18,20,24,21],0,1], //e,f♯,a♯,c♯
["F#7#11",[48,52,56,58,14,18,22,24],0,1], //c,e,g♯,a♯
["F#7#9",[52,57,58,61,18,17,24,21],0,1], //e,a,a♯,c♯
["F#7alt",[52,57,58,62,18,17,12,16],1,1], //e,a,bb,d
["F#7b13",[54,58,62,64,20,24,16,18],0,1], //f♯,a♯,d,e
["F#7b9",[52,55,58,63,18,15,24,23],0,1], //e,g,a♯,d♯
["F#7sus",[54,56,59,64,20,22,19,18],0,1], //f♯,g♯,b,e
["F#7susb9",[54,55,59,64,20,15,19,18],0,1], //f♯,g,b,e
["F#dim",[54,57,60,63,20,17,14,11],22,1], //f♯,a,c,eb
["F#m(6/9)",[51,54,56,57,23,20,22,17],0,1], //d♯,f♯,g♯,a
["F#m7",[52,56,57,61,18,22,17,21],19,1], //e,g♯,a,c♯
["F#m7#5",[54,57,62,64,20,17,16,18],0,1], //f♯,a,d,e
["F#m7/E",[52,56,57,61,18,22,17,21],20,1], //e,g♯,a,c♯
["F#m7/F#",[54,57,61,64,20,17,21,18],1,1], //f♯,a,c♯,e
["F#m7b5",[52,54,57,60,18,20,17,14],17,2], //e,f♯,a,c
["F#m7b5",[54,59,60,64,20,19,14,18],1,1], //f♯,b,c,e
["F#m7b5/F#",[54,59,60,64,20,19,14,18],2,1], //f♯,b,c,e
["F#mMaj7",[54,57,61,65,20,17,21,25],1,1], //f♯,a,c♯,e♯
["F/F",[53,57,60,64,13,17,14,18],12,1], //f,a,c,e
["F6/9",[57,60,62,67,17,14,16,15],0,1], //a,c,d,g
["F7",[51,55,57,62,11,15,17,16],130,2], //eb,g,a,d
["F7",[57,62,63,67,17,16,11,15],18,1], //a,d,eb,g
["F7#11",[51,53,57,59,11,13,17,19],1,1], //eb,f,a,b
["F7#9",[51,56,57,60,11,10,17,14],0,1], //eb,ab,a,c
["F7/A",[57,62,63,67,17,16,11,15],1,1], //a,d,eb,g
["F7alt",[51,56,57,61,23,22,17,21],23,2], //d♯,g♯,a,c♯
["F7alt",[57,61,63,68,17,21,23,22],2,1], //a,c♯,d♯,g♯
["F7b13",[51,55,57,61,11,15,17,9],3,1], //eb,g,a,db
["F7b9",[51,54,57,62,11,20,17,16],14,1], //eb,f♯,a,d
["F7sus",[53,58,60,63,13,12,14,11],4,1],   //f,bb,c,eb
["F7susb9",[53,54,58,63,13,8,12,11],0,1], //f,gb,bb,eb
["Fdim",[53,56,59,62,13,10,19,16],9,1], //f,ab,b,d
["Fm(6/9)",[50,53,55,56,16,13,15,10],0,1], //d,f,g,ab
["Fm6",[53,56,60,62,13,10,14,16],0,1], //f,ab,c,d
["Fm7",[51,55,56,60,11,15,10,14],177,2], //eb,g,ab,c
["Fm7",[56,60,63,67,10,14,11,15],2,1], //ab,c,eb,g
["Fm7#5",[53,56,61,63,13,10,9,11],0,1], //f,ab,db,eb
["Fm7/Eb",[51,55,56,60,11,15,10,14],4,1], //eb,g,ab,c
["Fm7b5",[51,53,56,59,11,13,10,19],21,2], //eb,f,ab,b
["Fm7b5",[53,58,59,63,13,12,7,11],5,1], //f,bb,cb,eb
["Fm7b5/Eb",[51,53,56,59,11,13,10,19],1,1], //eb,f,ab,b
["FMaj#11",[55,57,59,64,15,17,19,18],0,1], //g,a,b,e
["FMaj#5",[53,57,61,64,13,17,21,18],0,1], //f,a,c♯,e
["FmMaj7",[52,53,56,60,18,13,10,14],9,1], //e,f,ab,c
["G",[54,55,59,62,20,15,19,16],65,1], //f♯,g,b,d
["G#7",[54,56,60,63,20,22,14,23],3,1], //f♯,g♯,c,d♯
["G#m7",[54,58,59,63,20,24,19,23],2,1],   //f♯,a♯,b,d♯
["G#m7b5",[56,61,62,66,22,21,16,20],0,1], //g♯,c♯,d,f♯
["G6/9",[47,50,52,57,19,16,18,17],0,1], //b,d,e,a
["G7",[53,57,59,64,13,17,19,18],198,1], //f,a,b,e
["G7#11",[55,59,61,65,15,19,21,13],3,1], //g,b,c♯,f
["G7#9",[53,58,59,62,13,12,19,16],1,1], //f,bb,b,d
["G7alt",[53,58,59,63,13,12,7,11],65,1], //f,bb,cb,eb
["G7b13",[53,57,59,63,13,17,19,11],6,1], //f,a,b,eb
["G7b9",[53,56,59,64,13,10,19,18],9,1], //f,ab,b,e
["G7sus",[53,55,60,62,13,15,14,16],2,1],   //f,g,c,d
["G7susb9",[55,56,60,65,15,10,14,13],0,1], //g,ab,c,f
["Gb",[53,54,58,61,13,8,12,9],12,1], //f,gb,bb,db
["Gb6/9",[49,51,56,58,9,11,10,12],0,1], //db,eb,ab,bb
["Gb7",[52,56,58,63,18,10,12,11],26,1], //e,ab,bb,eb
["Gb7#11",[48,52,56,58,14,18,22,24],0,1], //c,e,g♯,a♯
["Gb7sus",[54,59,61,64,8,19,9,18],2,2], //gb,b,db,e
["Gb7sus",[54,56,59,64,8,10,19,18],1,1], //gb,ab,b,e
["Gbdim",[54,57,60,63,20,17,14,11],0,1], //f♯,a,c,eb
["Gbm6",[54,57,61,63,8,17,9,11],0,1], //gb,a,db,eb
["Gbm7",[52,54,57,61,18,20,17,21],0,1], //e,f♯,a,c♯
["Gbm7b5",[54,59,60,64,8,19,14,18],1,1],   //gb,b,c,e
["Gbmaj#11",[48,53,56,58,14,13,10,12],0,1], //c,f,ab,bb
["GbMaj#11",[54,58,60,65,8,12,14,13],0,1], //gb,bb,c,f
["GbMaj#5",[50,53,54,58,16,13,8,12],0,1], //d,f,gb,bb
["GbmMaj7",[53,54,57,61,13,8,17,9],1,1], //f,gb,a,db
["Gdim",[55,58,61,64,15,12,21,18],9,1], //g,bb,c♯,e
["Gm(6/9)",[52,55,57,58,18,15,17,12],0,1], //e,g,a,bb
["Gm6",[55,58,62,64,15,12,16,18],0,1], //g,bb,d,e
["Gm7",[53,57,58,62,13,17,12,16],185,1], //f,a,bb,d
["Gm7#5",[55,58,63,65,15,12,11,13],0,1], //g,bb,eb,f
["Gm7/F",[53,57,58,62,13,17,12,16],2,1], //f,a,bb,d
["Gm7b5",[53,55,58,61,13,15,12,9],16,1], //f,g,bb,db
["GMaj#11",[55,59,61,66,15,19,21,20],0,1], //g,b,c♯,f♯
["GMaj#5",[55,59,63,63,15,19,23,23],1,2], //g,b,d♯,d#
["GMaj#5",[47,51,54,55,19,23,20,15],0,1], //b,d♯,f♯,g
["GmMaj7",[54,55,58,62,20,15,12,16],2,1], //f♯,g,bb,d
];		
		//console.log('chords[0][2] = ' + chords[0][2]);
		// for (var c = 0; c < chords.length; c++){
		for (var c = 0; c < 20; c++){
			cursor.staffIdx = 0;
			var harmony = newElement(Element.HARMONY);
            harmony.text = chords[c][0];
            cursor.add(harmony);
			cursor.staffIdx = 1;
			var chord = chords[c][1];
            //addChord(cursor, chord, 2880);
			addChord(cursor, chord, 1920);
			
		}
		Qt.quit();
    } // end onRun
}
